#
# spec file for package lxqt-config
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           lxqt-config
Version:        2.1.0
Release:        2.2
Summary:        LXQt Control Center
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
URL:            https://github.com/lxqt/lxqt-config
Source0:        %{url}/releases/download/%{version}/%{name}-%{version}.tar.xz
Source1:        %{url}/releases/download/%{version}/%{name}-%{version}.tar.xz.asc
Source2:        %{name}.keyring
BuildRequires:  cmake >= 3.18.0
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkgconfig
BuildRequires:  qt6-gui-private-devel
BuildRequires:  cmake(KF6Screen) >= 6.0.0
BuildRequires:  cmake(KF6WindowSystem) >= 6.0.0
BuildRequires:  cmake(Qt6Concurrent) >= 6.6
BuildRequires:  cmake(Qt6DBus) >= 6.6
BuildRequires:  cmake(Qt6LinguistTools) >= 6.6
BuildRequires:  cmake(Qt6Svg) >= 6.6
BuildRequires:  cmake(Qt6Xml) >= 6.6
BuildRequires:  cmake(lxqt) >= %{version}
BuildRequires:  cmake(lxqt-menu-data) >= %{version}
BuildRequires:  cmake(lxqt2-build-tools) >= %{version}
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcb)
BuildRequires:  pkgconfig(xcb-randr)
BuildRequires:  pkgconfig(xcursor)
BuildRequires:  pkgconfig(xi)
BuildRequires:  pkgconfig(xorg-libinput)
BuildRequires:  pkgconfig(zlib)

%description
System Configuration and Control Center for LXQt

%lang_package

%prep
%autosetup -p1

%build
%cmake_qt6
%{qt6_build}

%install
%{qt6_install}
%fdupes -s %{buildroot}%{_datadir}

%find_lang %{name} --with-qt --all-name

%ldconfig_scriptlets

%files
%license LICENSE
%doc AUTHORS CHANGELOG README.md
%dir %{_qt6_libdir}/%{name}
%dir %{_datadir}/lxqt
%dir %{_datadir}/lxqt/icons
%{_bindir}/%{name}
%{_bindir}/%{name}-appearance
%{_bindir}/%{name}-brightness
%{_bindir}/%{name}-file-associations
%{_bindir}/%{name}-input
%{_bindir}/%{name}-locale
%{_bindir}/%{name}-monitor
%{_qt6_libdir}/%{name}/lib%{name}-cursor.so
%{_datadir}/applications/*.desktop
%{_datadir}/icons/hicolor/*/apps/brightnesssettings.svg
%{_datadir}/lxqt/icons/monitor.svg
%{_mandir}/man?/%{name}*.?%{?ext_man}

%files lang -f %{name}.lang
%dir %{_datadir}/lxqt
%dir %{_datadir}/lxqt/translations
%dir %{_datadir}/lxqt/translations/%{name}
%dir %{_datadir}/lxqt/translations/%{name}-appearance
%dir %{_datadir}/lxqt/translations/%{name}-brightness
%dir %{_datadir}/lxqt/translations/%{name}-cursor
%dir %{_datadir}/lxqt/translations/%{name}-file-associations
%dir %{_datadir}/lxqt/translations/%{name}-input
%dir %{_datadir}/lxqt/translations/%{name}-locale
%dir %{_datadir}/lxqt/translations/%{name}-monitor

%changelog
* Mon Nov 11 2024 Shawn Dunn <sfalken@opensuse.org>
- Removed Recommends: for -lang package, not needed
* Wed Nov  6 2024 Андрей Алыпов <and.november@opensuse.org>
- Update to version 2.1.0:
  * Pre-release changes (#1074)
  * Weblate commits (#1077)
  * Weblate commits (#1073)
  * Weblate commits (#1072)
  * Weblate commits (#1071)
  * Weblate commits (#1070)
  * Weblate commits (#1069)
  * Weblate commits (#1066)
  * Updated *.ts files for Luganda (#1067)
  * Weblate commits (#1060)
* Thu Apr 18 2024 Shawn Dunn <sfalken@opensuse.org>
- Update to 2.0.0:
  * Ported to Qt6
  * Improved the UI of monitor settings
  * Corrected tab orders of config dialogs
- Specfile cleanup and macro refactoring/updating
* Mon Jan  1 2024 Shawn Dunn <sfalken@opensuse.org>
- Added %%dir declarations for icon directories to clear buildfail
* Mon Nov  6 2023 Shawn Dunn <sfalken@opensuse.org>
- Updated to 1.4.0:
  * Fixed setting of primary monitor after a change in libkscreen
  * Fixed a problem about not being able to set the cursor or its
    size when Xresources from /etc is read.
  * Use lxqt-menu-data
  * Corrected some typos and improved the message about default
    monitor settings
* Sat Apr 15 2023 Shawn Dunn <sfalken@opensuse.org>
- Updated to 1.3.0:
  * Prevented a potential segfault when loading keyboard layout
    settings and updated the code of `lxqt-config-monitor` for
    libkscreen 5.26.90
- Removed lxqt-config-1.2.0-include.patch
* Tue Feb 14 2023 Michael Vetter <mvetter@suse.com>
- boo#1208217: Include kscreen mode header
  See also: gh/lxqt/lxqt-config#903
  Add lxqt-config-1.2.0-include.patch
* Sat Nov  5 2022 Shawn Dunn <sfalken@cloverleaf-linux.org>
- Update to 1.2.0:
  * Enhancements to theme list in appearance config dialog. Themes
    are always sorted alphabetically, user themes are distinguished,
    and theme folders can be opened by double clicking or by
    using context menus.
* Mon Aug  8 2022 Shawn Dunn <sfalken@cloverleaf-linux.org>
- create /etc/ld.so.conf.d/lxqt-config.conf to fix private library issue [boo#1201772,boo#1196707]
* Fri Apr 29 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.1.0:
  * Added a separate page for GTK style settings to LXQt Appearance
    Configuration.
  * Fixed manual editing of combo boxes in LXQt Locale Configuration.
  * Small enhancements and code cleanup.
* Mon Nov  8 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.0.0:
  * Made "Other Settings" work in Configuration Center.
  * Added support for saving and loading of Qt palettes.
* Fri Apr 16 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.17.1:
  * Fixed compilation against Qt < 5.15.
* Fri Apr 16 2021 Michael Vetter <mvetter@suse.com>
- Update 0.17.0:
  * Made lxqt-config-appearance work under Wayland.
  * Made the code cleaner and more up-to-date.
* Sun Nov 15 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.16.1:
  * Fix a regression in setting the acceleration speed of
    mouse/touchpad.
* Wed Nov  4 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.16.0:
  * Better UI for lxqt-config-brightness.
  * Avoid C++11 range for possible container detachment.
  * Only use QStringLiteral where it avoids allocations.
  * Initialize monitor settings config in "lxqt-config-monitor/monitor.h".
  * Use QFlags default constructor.
  * Fixed a crash in lxqt-config-monitor.
  * Fixed type associations and added "Default Application".
  * Detailed palette customization in lxqt-config-appearance.
  * Remember sizes of appearance and file associations dialogs.
* Mon Apr 27 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Changed lxqt-config.keyring to tsujan's key
* Sat Apr 25 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Removed lxqt-config-0.14.1-sort.patch: contained in upstream
- Update to version 0.15.0
  * Drag and drop of screens is improved and made easier in Monitor Settings.
  * configuration saving and warnings are fixed.
  * Applying GTK themes and mouse cursor settings are fixed in LXQt Appearance Configurations.
  * Obsolete mouse accel/sensitivity options are removed from Keyboard and Mouse Settings (the real settings are under Mouse and Touchpad).
  * Other fixes.
* Mon Jan 27 2020 Michael Vetter <mvetter@suse.com>
- bsc#1161365: Add lxqt-config-0.14.1-sort.patch
- Add buildreq on glib
* Mon Feb 25 2019 mvetter@suse.com
- Update to 0.14.1:
  * Apply button for appearance and input config dialogs
  * Updated translations
* Thu Jan 31 2019 Michael Vetter <mvetter@suse.com>
- Update to 0.14.0:
  * Introduced GTK appearance settings
  * Initial touchpad settings and improved input device handling
  * lxqt-config-brightness: Backlight control updated
  * lxqt-config-monitor: Monitor name is added to output.
  * Installed former missed man pages
- Move translation from lxqt-l10n into package
* Tue May 22 2018 mvetter@suse.com
- Update to 0.13.0:
  * Improved backlight functionality
  * lxqt-config-brightness: Sets minimum backlight value to 0
  * lxqt-config-input: Adds the ability to set the initial page
  * Add gamma(brightness) reset as a cli option
* Mon Oct 23 2017 mvetter@suse.com
- Update to 0.12.0:
  * Set patch version
  * Use $XDG_CONFIG_HOME/mimeapps.list for mime data instead of $XDG_DATA_HOME/applications/mimeapps.list (#129)
  * Don't export github templates
  * Update monitorsettingsdialog.ui
  * lxqt-config-locale: corrected/reworded Save Changed Settings dialog
  * Add/update *lt.desktop files
  * lxq-config-monitor: set Qt::AA_UseHighDpiPixmaps to true
  * lxqt-config-locale: set Qt::AA_UseHighDpiPixmaps to true
  * lxqt-config-input: set Qt::AA_UseHighDpiPixmaps to true
  * lxqt-config-file-ass.: set Qt::AA_UseHighDpiPixmaps to true
  * lxqt-config-brightness: set Qt::AA_UseHighDpiPixmaps to true
  * lxqt-config-appearance: set Qt::AA_UseHighDpiPixmaps to true
  * liblxqt-config-cursor: set Qt::AA_UseHighDpiPixmaps to true
  * Added QCommandLineParser and basic cli interface to lxqt-config-monitor
  * Added QCommandLineParser and basic cli interface to lxqt-config-locale
  * Added QCommandLineParser and basic cli interface to lxqt-config-input
  * Added QCommandLineParser and basic cli interface to lxqt-config-file-associations
  * Added version info to lxqt-config-brightness cli
  * Added QCommandLineParser and basic cli interface to lxqt-config-appearance
  * Added QCommandLineParser and basic cli interface to lxqt-config
  * Added LXQT_CONFIG_PATCH_VERSION
  * Fixed typo in appearance_pl_PL.desktop (#124)
  * i18n: added some *.desktop for Polish language
  * Fixes (#121)
  * appearance: Fix typo from @aca544479
  * lxqt-config-file-associations: Sets the initial focus (#120)
  * appearance: Add icon FollowColorScheme configuration (#119)
  * Show non-primary screens in UI. (#116)
  * Removes unneeded include_directories() entry
  * Fixes a FTBFS with CMake v3.8
  * Use const iterators
  * Update AUTHORS
- Remove post and postun
- Remove add-include-directory-for-uic-files.diff
* Tue Jun 20 2017 alarrosa@suse.com
- Add add-include-directory-for-uic-files.diff to fix a failing build by
  including the directory where uic files are generated.
* Thu Feb 23 2017 sfalken@opensuse.org
- Update to 0.11.1:
  * lxqt-config-monitor: remove unnecessary wait before settings load (#114)
  * Fix self icontheme update (#113)
  * liblxqt-config-cursor: Don't check for null pointer before deleting it
  * liblxqt-config-cursor: Explicitly ignore function return value
  * Updated and added *_da.desktop files and removed da_DK
  * Use FindXCB CMake module
  * Activate items on releasing Enter instead of pressing it. (#78)
  * Update and rename lxqt-config_fr_FR.desktop to lxqt-config_fr.desktop
  * Fix faulty link in README.md
  * if not set, set the build type to Release
  * Desktop entry files: Update French translation
  * lxqt-config: Avoid multiple spawn on auto-repeat
  * Fix loading of translations for brightness
  * Create lxqt-config-brightness_it.desktop
  * Remove cpack (#104)
  * lxqt-config-brightness: Add GenericName and Comment to desktop entry
* Sat Sep 24 2016 mvetter@suse.com
- Update to 0.11.0:
  * appearance: Avoid blocking when setting wallpaper
  * appearance: Do (not) change wallpaper with theme
  * all: Remove XdgIcon & XdgIconLoader usage
  * brightness: Add change confirmation dialog
  * brightness: Correct indentation
  * Update README.md
  * Replaces deprecated QStyleOptionViewItemVx
  * Add Catalan translations
  * Add and Update Arabic Translations for Desktop Files
  * lxqt-config-monitor: Correct loadsettings.cpp
  * lxqt-config-monitor: Use QGuiApplication
  * I18n: Fix Plural String (#94)
  * fixed crash when selecting "extended view" while second monitor is off (#91)
  * build: Add optional build for subcomponents
  * lxqt-config-appearance: Fix a null pointer dereference (#93)
  * Add README.md
  * lxqt-config-brightness: Remove compiler warning
  * lxqt-config-brightness: Add libxcb dependency
  * lxqt-config-brightness: Use *_LDFLAGS in target_link_libraries
  * lxqt-config-appearance: Use fewer XdgIcon* stuff (#92)
  * lxqt-config-appearance: Use the new XdgIconLoader library (#90)
  * build: Use external translations (#89)
  * ts-files removal (#88)
  * Use const references with the foreach iterator
  * translations: russian translation update (#85)
  * font config: make it possible to write custom fontconfig files (#83)
  * view: Use icon/decoration size based on styling
  * Set grid size according to font and icon sizes.
  * lxqt-config-brightness: Use arrow keys to change settings.
  * Desktop file translation to Spanish added.
  * lxqt-config-brigness: Set brightness value by command line.
  * Removed not needed LICENSE
  * lxqt-config-brightness: Increase or decrease brightness using command line.
  * Create lxqt-config-locale_it.desktop
  * Rename from lxqt-config-brightness-settings to  lxqt-config-brightness.
  * lxqt-config-brightness-settings: Some files changes their licenses from GPL to LGPL.
  * lxqt-config-brightness-settings lxqt translations module added.
  * lxqt-config-brightness-settings added.
  * fix typo skiping -> skipping
  * build: Fix FTBFS by reverting the @a7220cb
  * Bum year in AUTHORS
  * lxqt-config-brightness-settings has been added. It can change brightness and gamma. It's a X11 tool because libKScreen can not change brightness or gamma yet.
  * lxqt-config: Load/store window size on begin/end
  * categorizedview: Use correct signature
  * lxqt-config: Remove homemade "activation logic"
  * Settings are saved in QSettings format instead JSON format.
  * Set position widget used bad scale. The real widget size is not set until the widget is shown.
  * Remove blue square in GUI position
  * Fast options added.
  * GUI only lets one primary output.
  * Icons aren't installed.
  * Check KScreen reply is OK. Changes in interface.
  * liblxqt is used to write autostart entry.
  * Don't track IDE settings
  * KScreen is slow loading screen modes at starting. Wait for modes ready.
  * KScreen sometimes changes id of modes. If mode exists and it is OK,         settings will be applied.
  * Save settings dialog added.
  * Initial support for different paths of xkb base.lst in different OSes.
  * A couple of bug fixes Check if the memory was allocated after malloc() and realloc() calls Fix typo
  * Update german translation
  * Fix warning on translation
  * Replace slang with a more traditional wording
  * build: Use CMAKE_INSTALL_FULL_LIBDIR for RPATH
  * Fixes an FTBFS on lxqt-config-locale_ru.desktop
  * Update Russian translations
  * apearance: Support "System" theme preview
  * Italian translation update
  * lxqt-config: Add CTRL+Q shortcut for closing
  * _hu.ts files updated, *hu_HU.ts files deleted
  * Mkdir $XDG_CONFIG_HOME/autostart or ~/.config/autostart, if not exists.
  * lxqt-config-appearance: Choose the icon with the matching size
- Remove lxqt-config-monitor_save-config-in-proper-place.patch: upstreamed
- Add keyring
* Sat Mar 12 2016 mvetter@suse.com
- Adding lxqt-config-monitor_save-config-in-proper-place.patch:
  Needed to save config where its suppoed to be. Used from upstream and can be removed upon next release.
* Fri Nov 13 2015 mvetter@suse.com
- Get rid of ldconfig hack and use proper RPATH
* Tue Nov 10 2015 mvetter@suse.com
- Remove patch:
  lxqt-config-libqt5.5.patch - Not needed anymore
* Mon Nov  9 2015 hrvoje.senjan@gmail.com
- Use a standard way to add non-standard libraries into LD_LIBRARY_PATH,
  instead of messing with fake binaries
* Mon Nov  9 2015 mvetter@suse.com
- lxqt-config 0.10 needs RPATH since it seems I cant use that
  I am using a wrapper script for /usr/bin/lxqt-config which
  tells is where to find the shared object files
* Thu Nov  5 2015 mvetter@suse.com
- Upstream release 0.10.0
- Removing patches:
  * fix_menu_categories.patch - got upstreamed.
  * fix_desktop_categories.patch - Using sed in spec file now.
* Tue Oct 13 2015 dimstar@opensuse.org
- Add lxqt-config-libqt5.5.patch: Fix build with libQt 5.5, which
  no longer implicitly includes everything.
* Tue Jun  2 2015 g.bluehut@gmail.com
- Added patch fix_menu_categories.patch
  lxqt-config will only show apps that have the "LXQt" Category, since we change the category to be freedesktop compliant ("X-LXQt") we need this fix
  so lxqt-config displays the apps (like appearance, powermanagement)
* Fri Feb 20 2015 sfalken@opensuse.org
- Changed %%build and %%install to use cmake macros
* Mon Feb  9 2015 sfalken@opensuse.org
- New upstream version 0.9.0
- Added -lang subpackage
- Added Patches
  + fix_desktop_categories.patch
* Tue Feb  3 2015 dvaleev@suse.com
- aarch64 ppc64 ppc64le have /usr/lib64 too
* Sun Jan 25 2015 sfalken@opensuse.org
- Added conditionals to enable Fedora builds
* Sat Oct 25 2014 andrea@opensuse.org
- new upstream version 0.8.0
* Tue May 13 2014 andrea@opensuse.org
- spec file cleanup for factory
* Tue May 13 2014 sfalken@opensuse.org
- Specfile cleanup
* Mon May 12 2014 sfalken@opensuse.org
- removed fedora spec, split into subproject
  Del:  lxqt-config-Fedora_20.spec
* Sat May 10 2014 sfalken@opensuse.org
- Ran spec-cleaner on openSUSE specfile
* Fri May  9 2014 sfalken@opensuse.org
- Added specfile for Fedora_20
  Add:  lxqt-config-Fedora_20.spec
* Fri May  9 2014 sfalken@opensuse.org
- Added new tarball for stable release
  Add:  lxqt-config-0.7.0.tar.xz
  Del:  _service
* Fri Apr  4 2014 sfalken@opensuse.org
- Intial Source Upload
  Add: _service
  Add: lxqt-config.spec
  Add: lxqt-config.changes
